<!DOCTYPE html>
<html lang="en">
        <meta charset="UTF-8">
        <title>Page Title</title>
        <meta name="viewport" content="width=device-width,initial-scale=1">
        {% block header %}{% endblock %}
    <body>
        {% block content %}{% endblock %}
    </body>
</html>